OC.L10N.register(
    "settings",
    {
    "Unable to change password" : "N'eo ket  bet posupl cheñch ar ger-tremen",
    "Very weak password" : "Ger-tremen skanv kenan",
    "Weak password" : "Ger-tremen skanv",
    "So-so password" : "Ger-tremen skañvig",
    "Good password" : "Ger-tremen mat",
    "Strong password" : "Ger-tremen kreñv",
    "Groups" : "Strolladoù",
    "Group list is empty" : "Listenn strollat goulo",
    "Unable to retrieve the group list" : "Dibosupl eo adtapout al listenn strollad",
    "{actor} added you to group {group}" : "{actor} en deus ouzhpennet ac'hnnoc'h er strollad {group}",
    "You added {user} to group {group}" : "Ouzhpennet o peus {user} et strollad {group}",
    "{actor} added {user} to group {group}" : "{actor} En deus ouzhpennet {user} d'ar strollad {group}",
    "An administrator added you to group {group}" : "Ar merour en deus ouzhpennet ac'hannoc'h d'ar strollad {group}",
    "An administrator added {user} to group {group}" : "Ar merour en deus ouzhpennet {user} d'ar strollad {group}",
    "{actor} removed you from group {group}" : "{actor} a zo bet lamet eus ar strollad {group}",
    "You removed {user} from group {group}" : "Lammet o peus {user} eus ar strollad {group}",
    "{actor} removed {user} from group {group}" : "{actor} en deus lmmet {user} eus ar strollad {group}",
    "An administrator removed you from group {group}" : "Ar merour en deus lammet ac'hanoc'h eus ar strollad {group}",
    "An administrator removed {user} from group {group}" : "Ar merour en deus lamet {user} eus ar strollad {group}",
    "Your <strong>group memberships</strong> were modified" : "Ho <strong>gwirioù strollad</strong> a zo bet cheñchet",
    "{actor} changed your password" : "{actor} en deus chechet o ger-tremen",
    "You changed your password" : "Cheñchet o peus o ger-tremen",
    "Your password was reset by an administrator" : "Ho ger-tremen a zo bet cheñchet gant ar merour",
    "Your password was reset" : "Cheñchet eo bet o ger-tremen",
    "{actor} changed your email address" : "{actor} en deus cheñchet o chom-lec'h postel",
    "You changed your email address" : "Cheñchet o peus ho chom-lec'h postel",
    "Your email address was changed by an administrator" : "Cheñchet eo bet ho chom-lec'h postel gant an merour",
    "You deleted app password \"{token}\"" : "Lamet ho peus ar ger-tremen meziant \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Adanvet ho peus ar ger-tremen meziant eus \"{token}\" da \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Aotreañ a rit ar restroù sistem da tizañ ar ger-tremen meziant \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Difennet o peus d'ar restroù sistem da dizañ ar ger-tremen meziant \"{token}\"",
    "Security" : "Surentez",
    "You successfully logged in using two-factor authentication (%1$s)" : "Deuet oc'h tre mat en ur implijout un dilesa daou-elfenn (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "C'hwitet eo ar mont tre gant un dilesa daou elfenn (%1$s)",
    "Remote wipe was started on %1$s" : "Groget eo al lemel pall da %1$s",
    "Remote wipe has finished on %1$s" : "Echuet eo bet al lemel pell da %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ho <strong>ger-tremen</strong> pe <strong>postel</strong> a zo bet cheñchet",
    "Settings" : "Arventennoù",
    "Wrong password" : "Ger-tremen fall",
    "Saved" : "Enrollet",
    "Authentication error" : "Fazi dilesa",
    "Wrong admin recovery password. Please check the password and try again." : "Ger-tremen adtapout ar merour fall. Gwiriit ar ger-tremen ha klaskit en dro.",
    "Administrator documentation" : "Dielvadur ar merour",
    "User documentation" : "Dielvadur an implijer",
    "Invalid SMTP password." : "Ger-tremen SMTP fall.",
    "Email setting test" : "Amprouiñ stumm ar postel",
    "Well done, %s!" : "Gouc'hemenoù, %s !",
    "If you received this email, the email configuration seems to be correct." : "Ma eo bet resevet ar postel ganeoc'h, stummadur ar bostel a seblant bezañ bet graet mat.",
    "Email could not be sent. Check your mail server log" : "N'eo ket posupl kas ar postel. Gwiriit kazetenn servijour evit ar bostel.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ur gudenn a zo bet en ur kas ar bostel. Adstummit o stumm (Fazi : %s)",
    "Invalid mail address" : "Chom-lec'h postel fall",
    "Settings saved" : "Stummoù enrollet",
    "Unable to change full name" : "N'haller ket cheñch an anv klok",
    "Unable to change email address" : "Dibosuple cheñch ar chom-lec'h postel",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Evit gwiriañ ho c'hont Twitter, kasit an tweet mañ war Twitter (bezit sur kas anezhañ hep teriñ al linenn) :",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Evit wiriañ ho Website, gwarnit an traoù goude en o gwrizienn-web e  '.well-known/CloudIdVerificationCode.txt' (bezit sur eo tout an destenn war ul linenn nemetken) :",
    "%1$s changed your password on %2$s." : "%1$s en deus cheñchet o ger-tremen war %2$s.",
    "Your password on %s was changed." : "Cheñchet eo bet o ger tremen war %s.",
    "Your password on %s was reset by an administrator." : "Cheñchet eo bet ho ger-tremen gant an merour war %s.",
    "Your password on %s was reset." : "Cheñchet eo bet o ger-tremen war %s.",
    "Password for %1$s changed on %2$s" : "O ger-tremen evit %1$s a zo bet cheñchet war %2$s",
    "Password changed for %s" : "Ger-tremen evit %s",
    "If you did not request this, please contact an administrator." : "Ma n'ho peus ket goullenet se, galvit o merour.",
    "Your email address on %s was changed." : "Cheñchet eo bet ho chom-lec'h postel war %s.",
    "Your email address on %s was changed by an administrator." : "Ho chom-lec'h postel war %s a zo bet cheñchet gant ar merour.",
    "Email address for %1$s changed on %2$s" : "Ar chom-lec'h postel evit %1$s a zo bet cheñchet war %2$s",
    "Email address changed for %s" : "Chom-lec'h postel cheñchet evit %s",
    "The new email address is %s" : "Ar chom-lec'h postel nevez a zo %s",
    "Your %s account was created" : "O c'hont %s a zo bet krouet",
    "Welcome aboard" : "Donemat e bourz",
    "Welcome aboard %s" : "Donemat e bourz %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Donemat d'ho c'hont %s, posupl eo deoc'h ouzhpennañ, gwarezi ha rannañ o roadennoù.",
    "Set your password" : "Lakaat ho ger-tremen",
    "Go to %s" : "Mont da %s",
    "Install Client" : "Stalia ar c'hliant",
    "Apps" : "Meziant",
    "Personal" : "Personel",
    "Administration" : "Merouriez",
    "Users" : "Implijer",
    "Additional settings" : "Stummoù ouzhpenn",
    "Assistant" : "Skoazeller",
    "Groupware" : "Labour a stroll",
    "Overview" : "Taol-lagad",
    "Basic settings" : "Stummoù diazez",
    "Sharing" : "Rannan",
    "Calendar" : "Deiziataer",
    "Personal info" : "Titouroù personel",
    "Mobile & desktop" : "Hezouk ha burev",
    "Email server" : "Servijour postel",
    "Background jobs" : "Labour diadreñv",
    "Unlimited" : "Didermenet",
    "Verifying" : "O gwiriañ",
    "Verifying …" : "O wiriañ...",
    "Verify" : "Gwiriañ",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankout a ra kolonennoù er roadennoù-diaz dibabapl. Abalamour e kemer amzer ouzhpennañ kolonennoù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-columns\" eo posupl ouzhpennañ ar c'holonennoù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ouzhpennet ar c'holonennoù, goulennoù savet d'an taolennoù a vo buanaet.",
    "Disabled" : "Disaotreañ",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Stumm ar sifrañ kostez ar servijour kozh a zo aotreet. Aliet eo hen disaotreañ.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "N'eo ket posupl implijout arc’hwel PHP \"set_time_limit\". Galout a ra ar gudenn-se herzel skriptoù e-kreiz o labour, terriñ ar staliadur. Aotreañ an arc'hwel a zo aliet-mat.",
    "Supported" : "Douget",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ho PHP ne zoug ket FreeType, terriñ ar skeudennoù profil ha stummoù an etrefas.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ne seblant ket bezañ staliet mat evit goulenn d'ar sistem argemennoù endro. An amprouenn gant getenv(\"PATH\") a ro ur respont goullo.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Aotreet a zo bet ar stumm lenn-nemetken. Ampechiñ a ra cheñch stummoù dre an etrefas-web. Ouzhpenn-se, ar restr en deus ezhomm bezañ adlakaet da  vezañ embannapl dre dorn evit pep adneveziñ.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Ho roadennoù-diaz ne droont ket gant al live \"READ COMMITTED\". Kudennoù a zo posupl kaout pa vez graet meur a ober war an dro.",
    "Nextcloud settings" : "Stummoù Nextcloud",
    "Enable" : "Aotreañ",
    "None" : "Hini ebet",
    "Allow apps to use the Share API" : "Aotreañ ar meziant d'a implijout Share API",
    "Allow resharing" : "Aotrea an adrannañ",
    "Allow sharing with groups" : "Aotreañ ar rannan gant ur strollad ",
    "Restrict users to only share with users in their groups" : "Redia an implijourien da ranna nemet gant an implijourien en o strolladoù",
    "Allow public uploads" : "Aotreañ ar bellkas publik",
    "Always ask for a password" : "Goulenn ar ger-tremen bewech.",
    "Enforce password protection" : "Rediañ ar gwarez dre ger-tremen",
    "Enforce expiration date" : "Rediañ an deiziat diamzerañ",
    "This text will be shown on the public link upload page when the file list is hidden." : "Diskouezet e vo an destenn war ar bajenn publik palkass liammoù pa eo kouachet ar roll restroù.",
    "Default share permissions" : "Aotreoù rannañ dre ziouer",
    "Two-Factor Authentication" : "Dilesa daou-elfenn",
    "Enforce two-factor authentication" : "Reddiañ an dilesa daou-elfenn",
    "Limit to groups" : "Nemet d'ar strolladoù",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Posupl eo rediañ an dilesa daou-elfenn da strolladoù 'zo nemetken.",
    "Two-factor authentication is enforced for all members of the following groups." : "Rediet eo an dilesa daou-elfenn da izili ar strolladoù didan.",
    "Enforced groups" : "Rediañ strollad",
    "Two-factor authentication is not enforced for members of the following groups." : "N'eo ket rediet an dilesa daoi-elfenn evit izili ar strolladoù dindan.",
    "Excluded groups" : "Strolladoù argaset",
    "Save changes" : "Enrollañ ar cheñchamantoù",
    "Update to {update}" : "Adnevesiñ da {update}",
    "Remove" : "Lemel",
    "Featured" : "Perzhiet",
    "This app is supported via your current Nextcloud subscription." : "Ar meziant-mañ a vez douget dre ho kommanant Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Meziantoù perzhiet a vez digeliet gant ha e-vbarzh ar gummuniezh. Perzhioù penna a vez roet gante ha prest int da krouiñ reoù all.",
    "Disable all" : "Difenn pep tra",
    "Icon" : "Skeudennig",
    "Name" : "Anv",
    "Version" : "Stumm",
    "Actions" : "Oberoù",
    "Results from other categories" : "Disoc'hoù evit rummadoù all",
    "No apps found for your version" : "Meziant ebet kavet evit ar stumm",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ","%n meziant a zo posuple adnevesiñ"],
    "Loading" : "Kargañ",
    "Type" : "Seurt",
    "Learn more" : "Deskiñ muioc'h",
    "Confirm" : "Kadarnañ",
    "Cancel" : "Nullañ",
    "Description" : "Deskrivadur",
    "View in store" : "Gwelet er stal",
    "Visit website" : "Mont war al lec'hienn",
    "Admin documentation" : "Dielvadur ar merour",
    "Developer documentation" : "Diellvadur an digeler",
    "Details" : "Munudoù",
    "All" : "Pep tra",
    "Limit app usage to groups" : "Lakaat ar meziant da veza implijet gant ar strolladoù nemetken",
    "No results" : "Disoc'h ebet",
    "Update to {version}" : "Oc'h adneveziñ da {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "N'eo ket posupl staliañ ar meziant peogwir n'eo ket bet graet war dro an amzalc'hioù :",
    "Categories" : "Rummadoù",
    "Documentation" : "Diellvadur",
    "Report a bug" : "Dugas ur gudenn",
    "Google Chrome for Android" : "Google Chrome evit Android",
    "{productName} Android app" : "{productName} Arload Android",
    "This session" : "An estez-mañ",
    "Marked for remote wipe" : "Market evit bezañ lamet a bell",
    "Device settings" : "Stummoù ardivink",
    "Allow filesystem access" : "Aotreañ an tremen d'ar restroù sistem",
    "Rename" : "Adenvel",
    "Revoke" : "Digargañ",
    "Wipe device" : "Lemel an dra",
    "Device" : "Ardivink",
    "Last activity" : "Oberenn divezhañ",
    "Devices & sessions" : "Ardivinkoù ha estezioù",
    "Web, desktop and mobile clients currently logged in to your account." : "Ar c'hliant Web, burev ha hezouk a zo kenstaget en ho c'hont.",
    "Error while creating device token" : "Ur fazi a zo bet en ur groiñ jedour an ardivink",
    "App name" : "Anv meziant",
    "Create new app password" : "Krouiñ ur ger-tremen meziant nevez",
    "Could not copy app password. Please copy it manually." : "N'eo ket posupl eilan ar ger-tremen meziant. Eilit anezhan gant an dorn.",
    "Login" : "Anv arveriad",
    "Password" : "Ger-tremen",
    "Show QR code for mobile apps" : "Diskouez ar c'hod QR evit ar meziant hezouk",
    "Use system cron service to call the cron.php file every 5 minutes." : "Implijit sevichoù ar sistem cron evit gervel restr cron.php pep 5 munutenn.",
    "Profile" : "Profil",
    "Server-side encryption" : "Sifradur ar servijour-goztez",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Sifradur kostez-srvijour aotre ar sifrañ restroù a vez pellkarget war ar servijour. Bevennet eo an ober, evel ur mont en dro gorekoc'h, n'a implijit se nemet m'az o peus ezhomm neuze.",
    "Enable server-side encryption" : "Aotrea sifradur kostez-servijour",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Modul sifrañ karget ebet, aotreit ar vodul sifrañ er roll meziantoù.",
    "Select default encryption module:" : "Choaz ur modul sifrañ dre ziouer :",
    "Enable encryption" : "Aotreañ ar sifradur",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ur wech lakaet ar sifradur, pep restr pellkarget war ar servijour diouzh al lec'h mañ a vo sifret war ar servijour. Ne vo posupl lemel ar sifrañ diwezatoc'h ma zoug ar vodul sifrañ ar geweriuster, ha pep amplegad a-raok (sellit ouzh penaos lakaat un alrc'hwez adtapout).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Ar sifradur nemetken na warant ket surentez ar sistem. Sellit ouz an dielvadur evit muioc'h a ditouroù diwar benn penaos e dro, sifradur ar meziantoù, hag ar an darvoudoù implij douget.",
    "Be aware that encryption always increases the file size." : "Gouzit eo vez kemeret muioc'h a blas gant ur restr sifret.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Mat eo kaout ur vackup reoliek eus o roadennoù, ha e bezit sur ober ur vackup eus an alrv'hwez sifrañ gant o roadennoù sifret.",
    "This is the final warning: Do you really want to enable encryption?" : "Kemenadenn diwall divezhañ : Sur oc'h aotreañ ar sifrañ ?",
    "Submit" : "Kinnig",
    "Current password" : "Ger-tremen hiziv",
    "New password" : "Ger-tremen nevez",
    "Picture provided by original account" : "Skeudenn roet gant ar c'hont orin",
    "Unable to update date of birth" : "N'haller ket cheñch an deiziad ganedigezh",
    "Enter your date of birth" : "Lakaat ho teiziad ganedigezh",
    "You are a member of the following groups:" : "Er strolladoù-mañ emaoc'h",
    "No email address set" : "Chom-lec'h postel ebet lakaet",
    "No language set" : "Yezh ebet lakaet",
    "Help translate" : "Sikour treiñ",
    "Week starts on {firstDayOfWeek}" : "Krog a ra ar sizunn gant {firstDayOfWeek}",
    "Your phone number" : "O niverenn pelgomzer",
    "Change" : "Cheñch",
    "Delete" : "Dilemel",
    "Reshare" : "Adrannañ",
    "School" : "Skol",
    "Default language" : "Yezh dre ziouer",
    "Common languages" : "Yezh boutiñ",
    "Password change is disabled because the master key is disabled" : "N'eo ket aotreet cheñch ger-tremen peogwir n'eo ket aotreet an alc'hwez meur",
    "Display name" : "Anv ardivink",
    "Email" : "Postel",
    "Quota" : "Quota",
    "Language" : "Yezh",
    "Avatar" : "Avatar",
    "Group admin for" : "Strollad merour evit",
    "Storage location" : "Lec'h berniañ",
    "Last login" : "Mont-tre divezhañ",
    "{size} used" : "{size} implijet",
    "Resend welcome email" : "Adkas ar postel degemer mat",
    "Remote wipe of devices" : "Lemel a bell an ardivink",
    "Wipe {userid}'s devices" : "Lemel ardivink {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Lemet eo bet penn-da-benn kont {userid} gant pep restr personnel, roadennoù meziant, hag-all-hag-all.",
    "Account deletion" : "Lemel ar c'hont",
    "Delete {userid}'s account" : "Dilemel kont {userid}",
    "Welcome mail sent!" : "Postel degemer kaset !",
    "Done" : "Graet",
    "Edit" : "Embann",
    "Show storage path" : "Diskouez an hent klenkañ",
    "Show last login" : "Diskouez ar c'hennask diwezhañ",
    "Send email" : "Kas postel",
    "Default quota" : "Quota dre ziouer",
    "Select default quota" : "Choaz ar c'hota dre ziouer",
    "Server error while trying to complete WebAuthn device registration" : "Ur fazi servijour a zo bet pa oa glotaet an ardivink WebAuthn",
    "Passwordless authentication requires a secure connection." : "Ret eo kaout ur c'henstagadur sur evit un dilesa di-ger-tremen.",
    "Add WebAuthn device" : "Ouzhpenn ardivink WebAuthn",
    "Please authorize your WebAuthn device." : "Aotreit o ardivink WebAuthn.",
    "Unnamed device" : "Ardivink hep anv",
    "Passwordless Authentication" : "Dilesa hep ger-tremen",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Lakaat o c'hont da implij an dilesa hap ger-tremen en ur heuliañ ar standart FIDO2.",
    "No devices configured." : "Ardivink stummet ebet.",
    "The following devices are configured for your account:" : "Stummet eo bet an ardivinkoù ma d'ho c'hont.",
    "Your browser does not support WebAuthn." : "Ne vez ket douget WebAuthn gant o furcher.",
    "Security & setup warnings" : "Kemmenadennoù suretez ha stumm",
    "All checks passed." : "Pep gwiriekadenn tremenat.",
    "There are some errors regarding your setup." : "Fazioù 'zo liammet do staliadur.",
    "There are some warnings regarding your setup." : "Diwal a zo liammet d'o staliadur.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Evel ar merour eo posupl deoc'h stumañ pizh penaos e vez rannet. Sellit ouz an diellvadur evit muioc'h a ditouroù.",
    "Apply" : "Lakaat",
    "Admins" : "Merourien",
    "Sending…" : "O kas...",
    "Email sent" : "Postel kaset",
    "Location" : "Lec'hiadur",
    "Profile picture" : "Skeudenn brofil",
    "About" : "Diwar-benn",
    "Date of birth" : "Deiziad ganedigezh",
    "Full name" : "Anv klok",
    "Phone number" : "Niverenn bellgomz",
    "Role" : "Roll",
    "Website" : "Lec'hienn web",
    "Locale" : "Diabarzh",
    "Private" : "Prevez",
    "Local" : "Diabarzh",
    "Federated" : "Kevredet",
    "Only synchronize to trusted servers" : "Kempredañ da servijourioù fiziet nemetken",
    "Synchronize to trusted servers and the global and public address book" : "Kempreda da servijourioù fiziet ha d'al levr chom-lerc'hioù oublik a hollek",
    "Your apps" : "Ho meziantoù",
    "Active apps" : "Meziantoù lakaet en dro",
    "Disabled apps" : "Meziantoù disaotreet",
    "Updates" : "Adnevesadennoù",
    "App bundles" : "Strolladoù meziant",
    "Featured apps" : "Meziant perzhiet",
    "Hide" : "Kouacha",
    "Download and enable" : "Pellgargañ ha aotreañ",
    "Disable" : "Disaotreañ",
    "Unknown" : "Dianv",
    "Never" : "James",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aotreet eo bet ar meziant mes ezomm e deus bezhan adnevesaet. Kaset a voc'h d'ar bajenn adneveziñ a benn 5 eilenn.",
    "Do you really want to wipe your data from this device?" : "C'hoant o peus lemel ar roadennoù diouzh o ardivink ?",
    "Confirm wipe" : "Gwiriañ al lemel",
    "Error while wiping the device with the token" : "Ur fazi a zo bet en ul lemel an ardivink gant ar jedouer",
    "Error while updating device token name" : "Ur fazi a zo bet en ur adnevesiñ anv jedouer an ardivink",
    "Error while updating device token scope" : "Ur fazi a zo bet en ur adnevesiñ pellder ar jedouer",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Re a goulennoù a zo bet eus ar rouedat. Klaskit en dro diwezhatoc'h pe galvit ho merour m'az eus ur fazi.",
    "Error" : "Fazi",
    "Forum" : "Forum",
    "Legal notice" : "Meneg lezenn",
    "Open documentation" : "Digeriñ an dielvadur",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Pouezus eo stummañ ar servijour avit ma c'helfe kas posteloù, evit kemenadennoù pe posteloù evit cheñch ar ger-tremen.",
    "Send mode" : "Mod kas",
    "Encryption" : "Sifradur",
    "Sendmail mode" : "Mod kas-postel",
    "From address" : "Eus chom-lec'h",
    "Server address" : "Chom-lec'h ar servijour",
    "Port" : "Porzh",
    "Authentication required" : "Eus un dilesa ez eus ezhomp",
    "Credentials" : "Kretaatoù",
    "SMTP Password" : "Ger-tremen SMTP",
    "Save" : "Enrollañ",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Digelet gant {communityopen}kummuniezh NExtcloud{linkclose}, ar {githubopen}c'hod orin{linkclose} a zo dindan aotre {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Liamm d'hon bajenn Facebook",
    "Follow us on Mastodon" : "Heuliit arc'hanomp war Mastodon",
    "Check out our blog" : "Sellit ouzh hon vlog",
    "Subscribe to our newsletter" : "Koumannantit d'hon kemenadennoù nevesadur",
    "Use a second factor besides your password to increase security for your account." : "Implijour un eil-elfenn d'ho ger-tremen a gwella urentez o c'hont.",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "N'en deus ket ar meziant ur stumm izelañ evit Nextcloud. Ur fazi a vo en dazont.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ar meziant n'en deus ket ur stumm huela eus Nextcloud merked. Ur fazi vo en dazont.",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Ma peus kollet o ardivink pe kuitaet ar strollad, posupl e vefe lemet a pell roadennoù Nextcloud eus tout o ardivinkoù liamet gant {userid}. Ne gerzh nemet ma eo kenstaget an ardivinkoù gant internet.",
    "Adding your device …" : "Ouehpennit ho ardivink ...",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "N'eo ket ar meziant keverlec'h gant stumm Nextcloud. Ma kendalc'hit e o posupl deoc'h staliañ ar meziant. Taolit evez, ne labouro ket ar meziant evel ma zlefe.",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pouezus eo evit ar surentez hag ar mont en dro ho azgoulenn e vefe pep tra stummet mat. Evit sikour ac'hanoc'h e vez graet gwiradennoù otomatek. Sellit ouz an diellvadur liammet evit muioc'h a ditouroù.",
    "Checking for system and security issues." : "O gwiriañ ne vefe kuden ebet gant ar sistem hag ar surentez.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Sellit ouzh <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">sturier ar staliañ ↗</a>, ha gwiriit ne vefe fazi pe diwal ebet er <a href=\"%2$s\">gazetenn</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Gwiriit surentez ho Nextcoud war <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hon skan surentez ↗</a>."
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
